# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.generalHardcodedPassword

Module implementing checks for potentially hardcoded passwords.

### Global Attributes

RE_CANDIDATES
RE_WORDS

### Classes

None

### Functions

checkHardcodedPasswordAsDefault | Function to check for use of hard-coded password argument defaults.
checkHardcodedPasswordAsFunctionArg | Function to check for use of hard-coded password function arguments.
checkHardcodedPasswordAsString | Function to check for use of hardcoded password strings.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkHardcodedPasswordAsDefault

checkHardcodedPasswordAsDefault(reportError, context, _config)

Function to check for use of hard-coded password argument defaults.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## checkHardcodedPasswordAsFunctionArg

checkHardcodedPasswordAsFunctionArg(reportError, context, _config)

Function to check for use of hard-coded password function arguments.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## checkHardcodedPasswordAsString

checkHardcodedPasswordAsString(reportError, context, _config)

Function to check for use of hardcoded password strings.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
_config (dict)
  dictionary with configuration data (unused)

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up